Struct tm_protos::abci::RequestBeginBlock
source · [−]pub struct RequestBeginBlock {
pub hash: Vec<u8>,
pub header: Option<Header>,
pub last_commit_info: Option<LastCommitInfo>,
pub byzantine_validators: Vec<Evidence>,
}Fields
hash: Vec<u8>header: Option<Header>last_commit_info: Option<LastCommitInfo>byzantine_validators: Vec<Evidence>Trait Implementations
sourceimpl Clone for RequestBeginBlock
impl Clone for RequestBeginBlock
sourcefn clone(&self) -> RequestBeginBlock
fn clone(&self) -> RequestBeginBlock
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for RequestBeginBlock
impl Debug for RequestBeginBlock
sourceimpl Default for RequestBeginBlock
impl Default for RequestBeginBlock
sourceimpl Message for RequestBeginBlock
impl Message for RequestBeginBlock
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
Encodes the message to a buffer. Read more
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError> where
B: BufMut,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError> where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self. Read more
sourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError> where
B: Buf,
Decodes a length-delimited instance of the message from buffer, and
merges it into self. Read more
sourceimpl PartialEq<RequestBeginBlock> for RequestBeginBlock
impl PartialEq<RequestBeginBlock> for RequestBeginBlock
sourcefn eq(&self, other: &RequestBeginBlock) -> bool
fn eq(&self, other: &RequestBeginBlock) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &RequestBeginBlock) -> bool
fn ne(&self, other: &RequestBeginBlock) -> bool
This method tests for !=.
impl StructuralPartialEq for RequestBeginBlock