pub struct Header {Show 14 fields
pub version: Option<Consensus>,
pub chain_id: String,
pub height: i64,
pub time: Option<Timestamp>,
pub last_block_id: Option<BlockId>,
pub last_commit_hash: Vec<u8>,
pub data_hash: Vec<u8>,
pub validators_hash: Vec<u8>,
pub next_validators_hash: Vec<u8>,
pub consensus_hash: Vec<u8>,
pub app_hash: Vec<u8>,
pub last_results_hash: Vec<u8>,
pub evidence_hash: Vec<u8>,
pub proposer_address: Vec<u8>,
}Expand description
Header defines the structure of a Tendermint block header.
Fields
version: Option<Consensus>basic block info
chain_id: Stringheight: i64time: Option<Timestamp>last_block_id: Option<BlockId>prev block info
last_commit_hash: Vec<u8>hashes of block data
commit from validators from the last block
data_hash: Vec<u8>transactions
validators_hash: Vec<u8>hashes from the app output from the prev block
validators for the current block
next_validators_hash: Vec<u8>validators for the next block
consensus_hash: Vec<u8>consensus params for current block
app_hash: Vec<u8>state after txs from the previous block
last_results_hash: Vec<u8>root hash of all results from the txs from the previous block
evidence_hash: Vec<u8>consensus info
evidence included in the block
proposer_address: Vec<u8>original proposer of the block